@@ -1,32 +1,24 @@
 import logging
-logger = logging.getLogger(__name__)
-from ..utils import range_to_str, yprint
+import sqlite3
+from ..db import load_routine, list_routines
+from ..utils import range_to_str, yprint, run_routine
 
 
 def show_routine(args):
-    try:
-        from ..db import load_routine, list_routine
-        from .run import run_n_archive
-    except Exception as e:
-        logger.error(e)
-        return
-
     # List routines
     if args.routine_name is None:
-        routines = list_routine()[0]
-        if routines:
-            yprint(routines)
-        else:
+        try:
+            yprint(list_routines()[0])
+        except sqlite3.OperationalError:
             print('No routine has been saved yet')
         return
 
     try:
         routine, _ = load_routine(args.routine_name)
         if routine is None:
-            print(f'Routine {args.routine_name} not found')
             return
-    except Exception as e:
-        print(e)
+    except sqlite3.OperationalError:
+        print(f'Routine {args.routine_name} not found')
         return
 
     # Print the routine
@@ -35,4 +27,8 @@ def show_routine(args):
         yprint(routine)
         return
 
-    run_n_archive(routine, args.yes, False, args.verbose)
+    # Run the routine
+    try:
+        run_routine(routine, args.yes, None, args.verbose)
+    except Exception as e:
+        logging.error(e)
