@@ -1,9 +1,7 @@
 from pkg_resources import get_distribution
-from PyQt5.QtWidgets import QMainWindow, QMessageBox, QStackedWidget, QDesktopWidget
-# from PyQt5.QtWidgets import QMenuBar, QMenu
+from PyQt5.QtWidgets import QMainWindow, QStackedWidget, QDesktopWidget
 from ..pages.home_page import BadgerHomePage
 from ..pages.routine_page import BadgerRoutinePage
-from ..pages.run_page import BadgerRunPage
 
 
 class BadgerMainWindow(QMainWindow):
@@ -16,23 +14,17 @@ class BadgerMainWindow(QMainWindow):
     def init_ui(self):
         version = get_distribution('badger-opt').version
         self.setWindowTitle(f'Badger v{version}')
-        self.resize(960, 720)
+        # self.setWindowIcon(QIcon('badger.png'))
+        self.resize(864, 648)
         self.center()
 
-        # Add menu bar
-        # menu_bar = self.menuBar()
-        # edit_menu = menu_bar.addMenu('Edit')
-        # edit_menu.addAction('New')
-
         # Add pages
-        self.home_page = BadgerHomePage(self.show_routine_page, self.show_run_page)
+        self.home_page = BadgerHomePage(self.show_routine_page)
         self.routine_page = BadgerRoutinePage(self.show_home_page)
-        self.run_page = BadgerRunPage(self.show_routine_page, self.show_home_page)
 
         self.stacks = stacks = QStackedWidget()
         stacks.addWidget(self.home_page)
         stacks.addWidget(self.routine_page)
-        stacks.addWidget(self.run_page)
 
         stacks.setCurrentIndex(0)
 
@@ -49,24 +41,10 @@ class BadgerMainWindow(QMainWindow):
         pass
 
     def show_routine_page(self, routine=None):
-        try:
-            self.routine_page.refresh_ui(routine)
-        except Exception as e:
-            return QMessageBox.critical(self, 'Error!', str(e))
-
+        self.routine_page.refresh_ui(routine)
         self.stacks.setCurrentIndex(1)
 
     def show_home_page(self):
-        self.routine_page.refresh_ui(None)  # clean up to prevent bugs
         self.home_page.refresh_ui()
         self.home_page.reconfig_logic()
         self.stacks.setCurrentIndex(0)
-
-    def show_run_page(self):
-        try:
-            self.run_page.refresh_ui()
-            self.run_page.reconfig_logic()
-        except Exception as e:
-            return QMessageBox.critical(self, 'Error!', str(e))
-
-        self.stacks.setCurrentIndex(2)
